@@ -28,11 +28,11 @@ import (
 	. "github.com/onsi/gomega"
 	. "github.com/onsi/gomega/gstruct"
 
-	v1 "k8s.io/api/core/v1"
+	corev1 "k8s.io/api/core/v1"
 	"k8s.io/utils/pointer"
 
 	. "github.com/apache/camel-k/e2e/support"
-	camelv1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 )
 
 func TestTolerationTrait(t *testing.T) {
@@ -46,17 +46,17 @@ func TestTolerationTrait(t *testing.T) {
 				"-t", "toleration.enabled=true",
 				"-t", "toleration.taints=camel.apache.org/master:NoExecute:300",
 			).Execute()).To(Succeed())
-			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(v1.PodRunning))
-			Eventually(IntegrationCondition(ns, name, camelv1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(v1.ConditionTrue))
+			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
+			Eventually(IntegrationConditionStatus(ns, name, v1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 			Eventually(IntegrationLogs(ns, name), TestTimeoutShort).Should(ContainSubstring("Magicstring!"))
 
 			pod := IntegrationPod(ns, name)()
 			Expect(pod.Spec.Tolerations).NotTo(BeNil())
 
-			Expect(pod.Spec.Tolerations).To(ContainElement(v1.Toleration{
+			Expect(pod.Spec.Tolerations).To(ContainElement(corev1.Toleration{
 				Key:               "camel.apache.org/master",
-				Operator:          v1.TolerationOpExists,
-				Effect:            v1.TaintEffectNoExecute,
+				Operator:          corev1.TolerationOpExists,
+				Effect:            corev1.TaintEffectNoExecute,
 				TolerationSeconds: pointer.Int64Ptr(300),
 			}))
 		})
@@ -68,17 +68,17 @@ func TestTolerationTrait(t *testing.T) {
 				"-t", "toleration.enabled=true",
 				"-t", "toleration.taints=camel.apache.org/master=test:NoExecute:300",
 			).Execute()).To(Succeed())
-			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(v1.PodRunning))
-			Eventually(IntegrationCondition(ns, name, camelv1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(v1.ConditionTrue))
+			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
+			Eventually(IntegrationConditionStatus(ns, name, v1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 			Eventually(IntegrationLogs(ns, name), TestTimeoutShort).Should(ContainSubstring("Magicstring!"))
 
 			pod := IntegrationPod(ns, name)()
 			Expect(pod.Spec.Tolerations).NotTo(BeNil())
 
-			Expect(pod.Spec.Tolerations).To(ContainElement(v1.Toleration{
+			Expect(pod.Spec.Tolerations).To(ContainElement(corev1.Toleration{
 				Key:      "camel.apache.org/master",
-				Operator: v1.TolerationOpEqual,
-				Value:    "test", Effect: v1.TaintEffectNoExecute,
+				Operator: corev1.TolerationOpEqual,
+				Value:    "test", Effect: corev1.TaintEffectNoExecute,
 				TolerationSeconds: pointer.Int64Ptr(300),
 			}))
 		})
@@ -99,27 +99,27 @@ func TestTolerationTrait(t *testing.T) {
 				"-t", "toleration.taints=node-role.kubernetes.io/master:NoSchedule",
 			).Execute()).To(Succeed())
 
-			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(v1.PodRunning))
-			Eventually(IntegrationCondition(ns, name, camelv1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(v1.ConditionTrue))
+			Eventually(IntegrationPodPhase(ns, name), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
+			Eventually(IntegrationConditionStatus(ns, name, v1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 			Eventually(IntegrationLogs(ns, name), TestTimeoutShort).Should(ContainSubstring("Magicstring!"))
 
 			pod := IntegrationPod(ns, name)()
 			Expect(pod).NotTo(BeNil())
 
 			// Check the Integration pod contains the toleration
-			Expect(pod.Spec.Tolerations).To(ContainElement(v1.Toleration{
+			Expect(pod.Spec.Tolerations).To(ContainElement(corev1.Toleration{
 				Key:      "node-role.kubernetes.io/master",
-				Operator: v1.TolerationOpExists,
-				Effect:   v1.TaintEffectNoSchedule,
+				Operator: corev1.TolerationOpExists,
+				Effect:   corev1.TaintEffectNoSchedule,
 			}))
 
 			// Check the Integration pod is running on a master node
 			Expect(Node(pod.Spec.NodeName)()).NotTo(BeNil())
 			Expect(Node(pod.Spec.NodeName)()).To(PointTo(MatchFields(IgnoreExtras, Fields{
 				"Spec": MatchFields(IgnoreExtras, Fields{
-					"Taints": ContainElement(v1.Taint{
+					"Taints": ContainElement(corev1.Taint{
 						Key:    "node-role.kubernetes.io/master",
-						Effect: v1.TaintEffectNoSchedule,
+						Effect: corev1.TaintEffectNoSchedule,
 					}),
 				}),
 			})))
