@@ -18,6 +18,8 @@ limitations under the License.
 package v1
 
 import (
+	"encoding/json"
+	"errors"
 	"fmt"
 )
 
@@ -25,11 +27,19 @@ func (in *Artifact) String() string {
 	return in.ID
 }
 
+func (in *MavenArtifact) GetDependencyID() string {
+	switch {
+	case in.Version == "":
+		return "mvn:" + in.GroupID + ":" + in.ArtifactID
+	default:
+		return "mvn:" + in.GroupID + ":" + in.ArtifactID + ":" + in.Version
+	}
+}
+
 func (in *ConfigurationSpec) String() string {
 	return fmt.Sprintf("%s=%s", in.Type, in.Value)
 }
 
-// CapabilityDependencies ---
 func (in *RuntimeSpec) CapabilityDependencies(capability string) []MavenArtifact {
 	deps := make([]MavenArtifact, 0)
 
@@ -39,3 +49,23 @@ func (in *RuntimeSpec) CapabilityDependencies(capability string) []MavenArtifact
 
 	return deps
 }
+
+// MarshalJSON returns m as the JSON encoding of m.
+func (m RawMessage) MarshalJSON() ([]byte, error) {
+	if m == nil {
+		return []byte("null"), nil
+	}
+	return m, nil
+}
+
+// UnmarshalJSON sets *m to a copy of data.
+func (m *RawMessage) UnmarshalJSON(data []byte) error {
+	if m == nil {
+		return errors.New("json.RawMessage: UnmarshalJSON on nil pointer")
+	}
+	*m = append((*m)[0:0], data...)
+	return nil
+}
+
+var _ json.Marshaler = (*RawMessage)(nil)
+var _ json.Unmarshaler = (*RawMessage)(nil)
