@@ -21,13 +21,13 @@ import (
 	"context"
 	"strings"
 
-	"github.com/apache/camel-k/pkg/util/defaults"
 	"github.com/go-logr/logr"
 
 	"github.com/apache/camel-k/pkg/client"
+	"github.com/apache/camel-k/pkg/util/defaults"
 )
 
-// OperatorStartupOptionalTools tries to install optional tools at operator startup and warns if something goes wrong
+// OperatorStartupOptionalTools tries to install optional tools at operator startup and warns if something goes wrong.
 func OperatorStartupOptionalTools(ctx context.Context, c client.Client, namespace string, operatorNamespace string, log logr.Logger) {
 	// Try to register the OpenShift CLI Download link if possible
 	if err := OpenShiftConsoleDownloadLink(ctx, c); err != nil {
@@ -63,4 +63,10 @@ func OperatorStartupOptionalTools(ctx context.Context, c client.Client, namespac
 			}
 		}
 	}
+
+	// Try to bind the Knative Addressable resolver aggregated ClusterRole to the operator ServiceAccount
+	if err := BindKnativeAddressableResolverClusterRole(ctx, c, namespace); err != nil {
+		log.Info("Cannot bind the Knative Addressable resolver aggregated ClusterRole: skipping.")
+		log.V(8).Info("Error while binding the Knative Addressable resolver aggregated ClusterRole", "error", err)
+	}
 }
