@@ -30,13 +30,13 @@ import (
 	"github.com/apache/camel-k/pkg/util/log"
 )
 
-// Catalog collects all information about traits in one place
+// Catalog collects all information about traits in one place.
 type Catalog struct {
 	L      log.Logger
 	traits []Trait
 }
 
-// NewCatalog creates a new trait Catalog
+// NewCatalog creates a new trait Catalog.
 func NewCatalog(c client.Client) *Catalog {
 	traitList := make([]Trait, 0, len(FactoryList))
 	for _, factory := range FactoryList {
@@ -141,7 +141,7 @@ func (c *Catalog) apply(environment *Environment) error {
 	return nil
 }
 
-// GetTrait returns the trait with the given ID
+// GetTrait returns the trait with the given ID.
 func (c *Catalog) GetTrait(id string) Trait {
 	for _, t := range c.AllTraits() {
 		if t.ID() == ID(id) {
@@ -151,7 +151,7 @@ func (c *Catalog) GetTrait(id string) Trait {
 	return nil
 }
 
-// ComputeTraitsProperties returns all key/value configuration properties that can be used to configure traits
+// ComputeTraitsProperties returns all key/value configuration properties that can be used to configure traits.
 func (c *Catalog) ComputeTraitsProperties() []string {
 	results := make([]string, 0)
 	for _, trait := range c.AllTraits() {
@@ -182,3 +182,9 @@ func (c *Catalog) processFields(fields []*structs.Field, processor func(string))
 		}
 	}
 }
+
+type Finder interface {
+	GetTrait(id string) Trait
+}
+
+var _ Finder = &Catalog{}
