@@ -21,17 +21,18 @@ import (
 	"fmt"
 	"strings"
 
+	yaml2 "gopkg.in/yaml.v2"
+
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/util/uri"
-	yaml2 "gopkg.in/yaml.v2"
 )
 
-// YAMLInspector --
+// YAMLInspector --.
 type YAMLInspector struct {
 	baseInspector
 }
 
-// Extract --
+// Extract --.
 func (i YAMLInspector) Extract(source v1.SourceSpec, meta *Metadata) error {
 	definitions := make([]map[string]interface{}, 0)
 
@@ -160,14 +161,14 @@ func (i YAMLInspector) parseStep(key string, content interface{}, meta *Metadata
 		switch key {
 		case "from":
 			meta.FromURIs = append(meta.FromURIs, maybeURI)
-		case "to":
+		case "to", "to-d":
 			meta.ToURIs = append(meta.ToURIs, maybeURI)
 		}
 	}
 	return nil
 }
 
-// TODO nolint: gocyclo
+// TODO nolint: gocyclo.
 func (i YAMLInspector) parseStepsParam(steps []interface{}, meta *Metadata) error {
 	for _, raw := range steps {
 		if step, stepFormatOk := raw.(map[interface{}]interface{}); stepFormatOk {
