@@ -23,8 +23,11 @@ repo=$1
 branch=$2
 
 cd $location/../
-target=./deploy/kamelets
+target=./build/_kamelets
+
+# Always recreate the dir
 rm -rf $target
+mkdir $target
 
 if [ "$repo" = "" ]; then
 	echo "no kamelet catalog defined: skipping"
@@ -32,7 +35,7 @@ if [ "$repo" = "" ]; then
 fi
 
 if [ "$branch" = "" ]; then
-  branch="master"
+  branch="main"
 fi
 
 echo "Cloning repository $repo on branch $branch to bundle kamelets..."
@@ -41,7 +44,6 @@ echo "Cloning repository $repo on branch $branch to bundle kamelets..."
 rm -rf ./tmp_kamelet_catalog
 git clone -b $branch --single-branch --depth 1 $repo ./tmp_kamelet_catalog
 
-mkdir $target
-cp ./tmp_kamelet_catalog/*.kamelet.yaml $target
+cp ./tmp_kamelet_catalog/kamelets/*.kamelet.yaml $target
 
 rm -rf ./tmp_kamelet_catalog
